@@ -28,8 +28,10 @@ def bind_unbind_address_on_database(database, acl_environment, acl_vlan, action=
 
     bind, created = DatabaseBind.objects.get_or_create(database= database,
                                                                                     bind_address= bind_address,
-                                                                                    defaults={'bind_status': CREATING}
+                                                                                    defaults={'bind_status': 0}
                                                                                     )
+    LOG.debug("Bind: {}, created? {}".format(bind, created))
+
     if not created:
         bind.bind_status = bind_status
         bind.save()
@@ -42,6 +44,8 @@ def bind_unbind_address_on_database(database, acl_environment, acl_vlan, action=
         custom_options['l4-options']['dest-port-start'] = instance.port
         data['rules'].append(custom_options)
 
+        LOG.debug("Creating bind for instance: {}".format(instance))
+
         bind_instance, created = InstanceBind.objects.get_or_create(instance= instance,
                                                                                                      bind_address= bind_address,
                                                                                                      defaults={'bind_status': CREATING}
@@ -50,6 +54,8 @@ def bind_unbind_address_on_database(database, acl_environment, acl_vlan, action=
             bind_instance.bind_status = bind_status
             bind_instance.save()
 
+        LOG.debug("InstanceBind: {}, created? {}".format(bind_instance, created))
+
     acl_credential = get_credentials_for(environment= database.environment, credential_type=CredentialType.ACLAPI)
     acl_client = AclClient(acl_credential.endpoint, acl_credential.user, acl_credential.password)
 
